@@ -71,7 +71,7 @@ class CogEnvDecoder:
                 self._thread.join()
         return self._env.close()
 
-    def reset(self, fri_cor=0.1, KP=8, KI=0, KD=2, VK1=0.375, M=3.4, Wheel_I=0.0125, obs_mat=False):
+    def reset(self, fri_cor=0.1, KP=8, KI=0, KD=2, VK1=0.375, M=3.4, Wheel_I=0.0125, Encoder_noise=0.01, obs_mat=False):
 
         if not self._force_sync:
             self._end_thread = True
@@ -86,6 +86,7 @@ class CogEnvDecoder:
         self._engine_Environment_channel.set_float_parameter("VK1", VK1)
         self._engine_Environment_channel.set_float_parameter("M", M)
         self._engine_Environment_channel.set_float_parameter("Wheel_I", Wheel_I)
+        self._engine_Environment_channel.set_float_parameter("Encoder_noise", Encoder_noise)
         if obs_mat == False:
             self._engine_Environment_channel.set_float_parameter("Obs_mat", float(0))
         else:
